Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(402)

Unified Diff: chrome/browser/ui/cocoa/website_settings/website_settings_bubble_controller.h

Issue 1995813002: Use the virtual URL of the page in the Page Info Bubble (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix Mac build Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/website_settings/website_settings_bubble_controller.h
diff --git a/chrome/browser/ui/cocoa/website_settings/website_settings_bubble_controller.h b/chrome/browser/ui/cocoa/website_settings/website_settings_bubble_controller.h
index 69a1a99846ffaaf468f80bb2fac6773f58a1f807..cea66d366d3eab472d9cbb03034f46c7496b5985 100644
--- a/chrome/browser/ui/cocoa/website_settings/website_settings_bubble_controller.h
+++ b/chrome/browser/ui/cocoa/website_settings/website_settings_bubble_controller.h
@@ -113,7 +113,7 @@ class WebsiteSettingsUIBridge : public content::WebContentsObserver,
// Creates a |WebsiteSettingsBubbleController| and displays the UI. |parent|
// is the currently active window. |profile| points to the currently active
// profile. |web_contents| points to the WebContents that wraps the currently
// active tab. |url| is the GURL of the currently active
// tab. |security_info| is the
// |security_state::SecurityStateModel::SecurityInfo| of
// the connection to the website in the currently active tab.
@@ -121,7 +121,7 @@ class WebsiteSettingsUIBridge : public content::WebContentsObserver,
gfx::NativeWindow parent,
Profile* profile,
content::WebContents* web_contents,
- const GURL& url,
+ const GURL& virtual_url,
const security_state::SecurityStateModel::SecurityInfo& security_info);
void set_bubble_controller(
@@ -113,7 +113,7 @@ class WebsiteSettingsUIBridge : public content::WebContentsObserver,
// is the currently active window. |profile| points to the currently active
// profile. |web_contents| points to the WebContents that wraps the currently
- // active tab. |url| is the GURL of the currently active
+ // active tab. |virtual_url| is the virtual GURL of the currently active
// tab. |security_info| is the
// |security_state::SecurityStateModel::SecurityInfo| of

Powered by Google App Engine
This is Rietveld 408576698